@@ -1,10 +1,12 @@
 mod alias;
 mod column;
 mod expression;
+mod with;
 
 pub use alias::{Alias, Aliasable};
 pub use column::Column;
 pub use expression::Expression;
+pub use with::{with, WithClause, WithQuery, WithQueryBuilder};
 
 pub type SortExpression = String;
 pub type Condition = String;
